@@ -27,9 +27,9 @@
 #include <gtk/gtk.h>
 #include "scrollarea.h"
 #define MATE_DESKTOP_USE_UNSTABLE_API
-#include <libmateui/mate-rr.h>
-#include <libmateui/mate-rr-config.h>
-#include <libmateui/mate-rr-labeler.h>
+#include <libmate-desktop/mate-rr.h>
+#include <libmate-desktop/mate-rr-config.h>
+#include <libmate-desktop/mate-rr-labeler.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 #include <glib/gi18n.h>
@@ -37,6 +37,10 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-bindings.h>
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define GdkRegion cairo_region_t
+#endif
+
 typedef struct App App;
 typedef struct GrabInfo GrabInfo;
 
@@ -229,7 +233,6 @@ add_key (GtkWidget *widget,
     GtkComboBox *box = GTK_COMBO_BOX (widget);
     GtkTreeModel *model = gtk_combo_box_get_model (box);
     GtkListStore *store = GTK_LIST_STORE (model);
-    gboolean retval;
 
     info.text = text;
     info.found = FALSE;
@@ -248,11 +251,6 @@ add_key (GtkWidget *widget,
                                            5, rotation,
                                            -1);
 
-	retval = TRUE;
-    }
-    else
-    {
-	retval = FALSE;
     }
 }
 
@@ -1492,7 +1490,11 @@ set_cursor (GtkWidget *widget, GdkCursorType type)
 	    gdk_window_set_cursor (window, cursor);
 
 	if (cursor)
+#if GTK_CHECK_VERSION (3, 0, 0)
+	    g_object_unref (cursor);
+#else
 	    gdk_cursor_unref (cursor);
+#endif
 }
 
 static void
@@ -2211,7 +2213,11 @@ get_output_for_window (MateRRConfig *configuration, GdkWindow *window)
     int largest_area;
     int largest_index;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gdk_window_get_geometry (window, &win_rect.x, &win_rect.y, &win_rect.width, &win_rect.height);
+#else
     gdk_window_get_geometry (window, &win_rect.x, &win_rect.y, &win_rect.width, &win_rect.height, NULL);
+#endif
     gdk_window_get_origin (window, &win_rect.x, &win_rect.y);
 
     largest_area = 0;
