@@ -12,6 +12,9 @@
 #include <X11/Xatom.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
 
 #include "wm-common.h"
 #include "capplet-util.h"
@@ -1935,7 +1938,9 @@ main (int argc, char *argv[])
   GtkBuilder *builder;
   GSettings *marco_settings;
 
+#if !GLIB_CHECK_VERSION (2, 32, 0)
   g_thread_init (NULL);
+#endif
   gtk_init (&argc, &argv);
 
   bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
