@@ -48,6 +48,10 @@
 #include <X11/Xcursor/Xcursor.h>
 #endif
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define GtkFunction GSourceFunc
+#endif
+
 enum
 {
 	DOUBLE_CLICK_TEST_OFF,
@@ -204,11 +208,11 @@ scrollmethod_gsettings_changed_event (GSettings *settings,
 				GtkBuilder *dialog)
 {
 	int scroll_method = g_settings_get_int (touchpad_settings, "scroll-method");
-	gtk_toggle_button_set_active (WID ("scroll_disabled_radio"),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("scroll_disabled_radio")),
 				scroll_method == 0);
-	gtk_toggle_button_set_active (WID ("scroll_edge_radio"),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("scroll_edge_radio")),
 				scroll_method == 1);
-	gtk_toggle_button_set_active (WID ("scroll_twofinger_radio"),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("scroll_twofinger_radio")),
 				scroll_method == 2);
 	gtk_widget_set_sensitive (WID ("horiz_scroll_toggle"),
 				 scroll_method != 0);
